Learn R Programming

IPEDSuploadables (version 3.0.1)

produce_com_report: Shortcut function with all steps to provide a Completions report

Description

Shortcut function with all steps to provide a Completions report

Usage

produce_com_report(
  df,
  extracips = NULL,
  part = "ALL",
  format = "uploadable",
  ugender = lifecycle::deprecated(),
  ggender = lifecycle::deprecated()
)

Value

A txt or csv file at the path of your choice

Arguments

df

A dataframe set up according to the readme

extracips

A dataframe set up according to the readme (optional)

part

A string with what part of the report you want to produce: 'all', 'A', etc.

format

A string ("uploadable" will produce a properly formatted upload file. "readable" will produce a csv of the upload file (only works for one part at a time). "both" will provide both options, but only works with one part at a time.

ugender

`r lifecycle::badge("deprecated")` A boolean: TRUE means you are collecting and able to report "another gender" for undergraduate completers, even if you have no (or few) such students. Set as FALSE if necessary. **Starting in 2025-2026, this argument will be ignored by later code.**

ggender

`r lifecycle::badge("deprecated")` A boolean: TRUE means you are collecting and able to report "another gender" for graduate completers, even if you have no (or few) such students. Set as FALSE if necessary. **Starting in 2025-2026, this argument will be ignored by later code.**

Examples

Run this code
# \dontshow{
#set temp directory for this example (not necessary for users)
.old_wd <- setwd(tempdir())
# }
# \donttest{
#entire report
produce_com_report(com_students, com_cips)

#one part as csv instead of key-value
produce_com_report(com_students, com_cips, part = "A", format = "readable")
# }

# \dontshow{
#reset directory for this example (not necessary for users)
setwd(.old_wd)
# }

Run the code above in your browser using DataLab