Learn R Programming

IPEDSuploadables (version 3.0.1)

produce_gr_report: Shortcut function with all steps to provide a Graduation Rates report

Description

Shortcut function with all steps to provide a Graduation Rates report

Usage

produce_gr_report(
  df,
  part = "ALL",
  format = "uploadable",
  ugender = lifecycle::deprecated()
)

Value

A txt or csv file at the path of your choice

Arguments

df

a dataframe set up according to the readme

part

a string with what part of the report you want to produce "all", "A1", etc.

format

A string ("uploadable" will produce a properly formatted upload file. "readable" will produce a csv of the upload file (only works for one part at a time). "both" will provide both options, but only works with one part at a time.

ugender

`r lifecycle::badge("deprecated")` A boolean: TRUE means you are collecting and able to report "another gender" for undergraduate students, even if you have no (or few) such students. Set as FALSE if necessary. **Starting in 2024-2025, this argument will be ignored by later code.**

Examples

Run this code
# \dontshow{
#set temp directory for this example (not necessary for users)
.old_wd <- setwd(tempdir())
# }
# \donttest{
#entire report
produce_gr_report(gr_students)

#one part in csv format instead of key-value
produce_gr_report(gr_students, part = "B", format = "readable")
# }
# \dontshow{
#reset directory for this example (not necessary for users)
setwd(.old_wd)
# }

Run the code above in your browser using DataLab