Learn R Programming

IPEDSuploadables (version 3.0.1)

produce_hr_report: Shortcut function with all steps to provide a Human Resources report

Description

Shortcut function with all steps to provide a Human Resources report

Usage

produce_hr_report(df, part = "all", format = "uploadable")

Value

A txt or csv file at the path of your choice

Arguments

df

a dataframe set up according to the readme

part

a string with what part of the report you want to produce "all", "A1", etc.

format

A string ("uploadable" will produce a properly formatted upload file. "readable" will produce a csv of the upload file (only works for one part at a time). "both" will provide both options, but only works with one part at a time.

Examples

Run this code
# \dontshow{
#set temp directory for this example (not necessary for users)
.old_wd <- setwd(tempdir())
# }
# \donttest{
#entire report
produce_hr_report(hr_staff)

#subsection with csv output instead of key-value txt
produce_hr_report(hr_staff, part = "A1", format = "readable")
# }
# \dontshow{
#reset directory for this example (not necessary for users)
setwd(.old_wd)
# }

Run the code above in your browser using DataLab