Learn R Programming

IPEDSuploadables (version 3.0.1)

produce_om_report: Shortcut function with all steps to provide an Outcome Measures report

Description

Shortcut function with all steps to provide an Outcome Measures report

Usage

produce_om_report(df, part = "ALL", format = "uploadable")

Value

A txt or csv file at the path of your choice

Arguments

df

A dataframe set up according to the readme

part

A string with what part of the report you want to produce: 'all', 'A', etc.

format

A string ("uploadable" will produce a properly formatted upload file. "readable" will produce a csv of the upload file (only works for one part at a time). "both" will provide both options, but only works with one part at a time.

Examples

Run this code
# \dontshow{
#set temp directory for this example (not necessary for users)
.old_wd <- setwd(tempdir())
# }

#entire report
produce_om_report(om_students)

#one part with csv output instead of key-value
produce_om_report(om_students, part = 'A', format = 'readable')

# \dontshow{
#reset directory for this example (not necessary for users)
setwd(.old_wd)
# }

Run the code above in your browser using DataLab