Learn R Programming

IPEDSuploadables (version 3.0.1)

produce_other_report: Produce an upload-compatible txt file from pre-aggregated files

Description

Use this function to create a key-value pair uploadable file from your own prepared dataframes, instead of using a different (provided) produce function. Your dataframes must be prepped to match final submission requirements as laid out by IPEDS (or whatever survey you will use this for. Use this function for one survey at a time, and add a separate dataframe for each part to the ... argument. See vignette for more details.

Usage

produce_other_report(..., survey = "MySurvey", part = "AllParts")

Value

txt file on your computer with the title

[survey]_[part]_[today's date].txt

Arguments

...

dataframes (one for each survey part, in order)

survey

string with the survey name you'd like in your filename

part

string with the part name (subname) you'd like your file name

Examples

Run this code
# \dontshow{
.old_wd <- setwd(tempdir())
# }
#With built-in R data
produce_other_report(mtcars[1:5,], iris[1:5,], ToothGrowth[1:5,], survey = 'FakeSurvey')
# \dontshow{
setwd(.old_wd)
# }
# \donttest{
#Will not execute properly (argument unnamed)
#produce_other_report(mtcars[1:5,], iris[1:5,], ToothGrowth[1:5,], 'FakeSurvey')
# }

Run the code above in your browser using DataLab